TermId

Struct TermId 

pub struct TermId(/* private fields */);
Index of a term in the look-up table.

Implementations

Source

impl TermId

pub fn run<'a, D: DataT>(&self, cv: Cv<'a, D>) -> ValXs<'a, D::V<'a>>

f.run((c, v)) returns the output of v | f in the context c.

pub fn paths<'a, D: DataT>( &self, cv: Cv<'a, D, (<D as DataT>::V<'a>, List<<D as DataT>::V<'a>>)>, ) -> ValXs<'a, (D::V<'a>, List<D::V<'a>>), D::V<'a>>

f.paths((c, (v, p))) returns the outputs and paths of v | f in the context c, where v is assumed to be at path p.

In particular, v | path(f) in context c yields the same paths as f.paths((c, (v, Default::default()))).

pub fn update<'a, D: DataT>( &self, cv: Cv<'a, D>, f: Box<dyn Update<'a, D::V<'a>> + 'a>, ) -> ValXs<'a, D::V<'a>>

p.update((c, v), f) returns the output of v | p |= f in the context c.