JustLut

Struct JustLut 

pub struct JustLut<V>(/* private fields */);
Filters that process V and take only LUT as data.

This restricts V to have a 'static lifetime. If you want to process V with arbitrary lifetimes instead, you need to define your own data kind and implement DataT for it.

This type is mostly used for testing.