Module parse

Module parse 

Parsing.

Structs

Def
jq definition, consisting of a name, optional arguments, and a body.
Parser
Parser for jq programs.

Enums

BinaryOp
Binary operators, such as |, ,, //, …
Expect
Type of token that we expected.
Pattern
Variable-binding pattern, such as in .[] as [$x, {$y, (f): $z}]
Term
Function from value to stream of values, such as .[] | add / length.

Type Aliases

Error
Parse error, storing what we expected and what we got instead.
Result
Output of a fallible parsing operation.
TError
Parse error that stores what token it found.