pub struct Exn<'a, V>(/* private fields */);Expand description
Exception.
This is either an error, a runtime halt, or control flow data internal to jaq. Users should only be able to observe the first two cases.
Use crate::unwrap_valr to convert a crate::ValX to an error.
Implementations