Native filter construction tools.
Functions
- bome
- Box Once and Map Errors to exceptions.
- run
- Convert a filter with a run pointer to a native filter.
- unary
- Create a filter that takes a single variable argument and whose output is given by
the function
fthat takes the input value and the value of the variable. - v
- Creates
nvariable arguments.
Type Aliases
- Filter
- Name, arguments, and implementation of a filter.
- Fun
- Native filter over a
crate::DataT.